Flow stuff (if/else, for/while/repeat, etc).
Flow stuff (if/else, for/while/repeat, etc).
(execute-cmd-with-open-window driver
{:keys [windowHandleName windowTimeout] :as cmd}
{vars :vars :as opt})(find-tests {:keys [test-id test-ids suite-id suite-ids test-name suite-name
test-names suite-names]}
{:keys [tests] :as parsed-file})(run-ide-script driver source & [opt])Run a Selenium IDE file.
Arguments:
driver: a driver instance;
source: either a file path, or an io/file, or an io/resource;
opt: a map of optional parameters:
-- :test-... and :suite-... (id, ids, name, names)
are used for selection of specific tests. When not passed,
all the tests get run;
-- :base-url the URL of the main page from which the tests start.
Use it override the default URL from an IDE file.
Run a Selenium IDE file.
Arguments:
- `driver`: a driver instance;
- `source`: either a file path, or an `io/file`, or an `io/resource`;
- `opt`: a map of optional parameters:
-- `:test-...` and `:suite-...` (`id`, `ids`, `name`, `names`)
are used for selection of specific tests. When not passed,
all the tests get run;
-- `:base-url` the URL of the main page from which the tests start.
Use it override the default URL from an IDE file.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |